@@ -770,7 +770,7 @@ fill_clock_applet(PanelApplet *applet)
 
 	create_clock_widget (cd);
 
-	gtk_container_set_border_width (GTK_CONTAINER (cd->applet), 4);
+	gtk_container_set_border_width (GTK_CONTAINER (cd->applet), 0);
 	gtk_container_add (GTK_CONTAINER (cd->applet), cd->clockw);
 
 	gtk_widget_show (cd->applet);
@@ -883,20 +883,10 @@ properties_response_cb (GtkWidget *widget,
 {
 	
 	if (id == GTK_RESPONSE_HELP) {
-		static GnomeProgram *applet_program = NULL;
 		GError *error = NULL;
 
-		if (!applet_program) {
-			int argc = 1;
-			char *argv[2] = { "clock" };
-			applet_program = gnome_program_init ("clock", VERSION,
-							      LIBGNOME_MODULE, argc, argv,
-							      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-		}
-
 		egg_help_display_desktop_on_screen (
-				applet_program, "clock",
-				"clock", "clock-settings",
+				NULL, "clock", "clock", "clock-settings",
 				gtk_widget_get_screen (cd->applet),
 				&error);
 
@@ -1126,18 +1116,9 @@ display_help_dialog (BonoboUIComponent *uic,
 		     const gchar       *verbname)
 {
 	GError *error = NULL;
-	static GnomeProgram *applet_program = NULL;
-
-	if (!applet_program) {
-		int argc = 1;
-		char *argv[2] = { "clock" };
-		applet_program = gnome_program_init ("clock", VERSION,
-						      LIBGNOME_MODULE, argc, argv,
-						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-	}
 
 	egg_help_display_desktop_on_screen (
-			applet_program, "clock", "clock",NULL,
+			NULL, "clock", "clock",NULL,
 			gtk_widget_get_screen (cd->applet),
 			&error);
 	if (error) {
@@ -1202,7 +1183,7 @@ display_about_dialog (BonoboUIComponent *uic,
 		g_warning (G_STRLOC ": gnome-clock.png cannot be found");
 
 	about = gnome_about_new (_("Clock"), VERSION,
-				 _("(C) 1998-2002 the Free Software Foundation"),
+				 "Copyright \xc2\xa9 1998-2002 Free Software Foundation. Inc.",
 				 _("The Clock displays the current time and date"),
 				 authors,
 				 documenters,
