@@ -77,7 +77,7 @@ aligned_pos_class_init (AlignedPosClass *klass)
 			      g_cclosure_marshal_VOID__ENUM,
 			      G_TYPE_NONE,
 			      1, 
-			      PANEL_TYPE_ALIGNED_ALIGNMENT);
+			      PANEL_TYPE_ALIGNMENT);
 
 	pos_class->set_pos = aligned_pos_set_pos;
 	pos_class->get_pos = aligned_pos_get_pos;
@@ -118,10 +118,10 @@ aligned_pos_set_pos (BasePWidget *basep,
 			return;
 	}
 	
-	innerx = x - multiscreen_x (basep->screen);
-	innery = y - multiscreen_y (basep->screen);
-	screen_width = multiscreen_width (basep->screen);
-	screen_height = multiscreen_height (basep->screen);
+	innerx = x - multiscreen_x (basep->screen, basep->monitor);
+	innery = y - multiscreen_y (basep->screen, basep->monitor);
+	screen_width = multiscreen_width (basep->screen, basep->monitor);
+	screen_height = multiscreen_height (basep->screen, basep->monitor);
 
 	/*if in the inner 1/3rd, don't change to avoid fast flickery
 	  movement*/
@@ -189,58 +189,59 @@ aligned_pos_get_pos (BasePWidget *basep, int *x, int *y,
 	*x = *y = 0;
 	switch (edge) {
 	case BORDER_BOTTOM:
-		*y = multiscreen_height(basep->screen) - h - foobar_widget_get_height (basep->screen);
+		*y = multiscreen_height (basep->screen, basep->monitor) -
+		     foobar_widget_get_height (basep->screen, basep->monitor) - h;
 		/* fall thru */
 	case BORDER_TOP:
-		*y += foobar_widget_get_height (basep->screen);
-		switch (ALIGNED_POS(basep->pos)->align) {
+		*y += foobar_widget_get_height (basep->screen, basep->monitor);
+		switch (ALIGNED_POS (basep->pos)->align) {
 		case ALIGNED_LEFT:
 			break;
 		case ALIGNED_CENTER:
-			*x = (multiscreen_width(basep->screen) - w) / 2;
+			*x = (multiscreen_width (basep->screen, basep->monitor) - w) / 2;
 			break;
 		case ALIGNED_RIGHT:
-			*x = multiscreen_width(basep->screen) - w;
+			*x = multiscreen_width (basep->screen, basep->monitor) - w;
 			break;
 		}
 		break;
 	case BORDER_RIGHT:
-		*x = multiscreen_width(basep->screen) - w;
-		basep_border_get (basep->screen, BORDER_TOP, NULL, NULL, &a);
-		basep_border_get (basep->screen, BORDER_BOTTOM, NULL, NULL, &b);
-		switch (ALIGNED_POS(basep->pos)->align) {
+		*x = multiscreen_width (basep->screen, basep->monitor) - w;
+		basep_border_get (basep, BORDER_TOP, NULL, NULL, &a);
+		basep_border_get (basep, BORDER_BOTTOM, NULL, NULL, &b);
+		switch (ALIGNED_POS (basep->pos)->align) {
 		case ALIGNED_LEFT:
-			*y = foobar_widget_get_height (basep->screen) + a;
+			*y = foobar_widget_get_height (basep->screen, basep->monitor) + a;
 			break;
 		case ALIGNED_CENTER:
-			*y = (multiscreen_height(basep->screen) - h) / 2;
+			*y = (multiscreen_height (basep->screen, basep->monitor) - h) / 2;
 			break;
 		case ALIGNED_RIGHT:
-			*y = multiscreen_height(basep->screen) - h - b;
+			*y = multiscreen_height (basep->screen, basep->monitor) - h - b;
 			break;
 		}
 		break;
 	case BORDER_LEFT:
-		basep_border_get (basep->screen, BORDER_TOP, &a, NULL, NULL);
-		basep_border_get (basep->screen, BORDER_BOTTOM, &b, NULL, NULL);
-		switch (ALIGNED_POS(basep->pos)->align) {
+		basep_border_get (basep, BORDER_TOP, &a, NULL, NULL);
+		basep_border_get (basep, BORDER_BOTTOM, &b, NULL, NULL);
+		switch (ALIGNED_POS (basep->pos)->align) {
 		case ALIGNED_LEFT:
-			*y = foobar_widget_get_height (basep->screen) + a;
+			*y = foobar_widget_get_height (basep->screen, basep->monitor) + a;
 			break;
 		case ALIGNED_CENTER:
-			*y = (multiscreen_height(basep->screen) - h) / 2;
+			*y = (multiscreen_height (basep->screen, basep->monitor) - h) / 2;
 			break;
 		case ALIGNED_RIGHT:
-			*y = multiscreen_height(basep->screen) - h - b;
+			*y = multiscreen_height (basep->screen, basep->monitor) - h - b;
 			break;
 		}
 		break;
 	}
 
-	*x += multiscreen_x (basep->screen);
-	*y += multiscreen_y (basep->screen);
+	*x += multiscreen_x (basep->screen, basep->monitor);
+	*y += multiscreen_y (basep->screen, basep->monitor);
 
-	basep_border_queue_recalc (basep->screen);
+	basep_border_queue_recalc (basep->screen, basep->monitor);
 }
 
 static void
@@ -285,6 +286,7 @@ aligned_pos_show_hide_right (BasePWidget *basep)
 void
 aligned_widget_change_params (AlignedWidget *aligned,
 			      int screen,
+			      int monitor,
 			      AlignedAlignment align,
 			      BorderEdge edge,
 			      int sz,
@@ -292,12 +294,12 @@ aligned_widget_change_params (AlignedWidget *aligned,
 			      BasePState state,
 			      gboolean hidebuttons_enabled,
 			      gboolean hidebutton_pixmaps_enabled,
-			      PanelBackType back_type,
+			      PanelBackgroundType back_type,
 			      char *pixmap_name,
 			      gboolean fit_pixmap_bg,
 			      gboolean stretch_pixmap_bg,
 			      gboolean rotate_pixmap_bg,
-			      GdkColor *back_color)
+			      PanelColor *back_color)
 {
 	AlignedPos *pos = ALIGNED_POS (BASEP_WIDGET (aligned)->pos);
 
@@ -310,6 +312,7 @@ aligned_widget_change_params (AlignedWidget *aligned,
 
 	border_widget_change_params (BORDER_WIDGET (aligned),
 				     screen,
+				     monitor,
 				     edge,
 				     sz,
 				     mode,
@@ -338,18 +341,19 @@ aligned_widget_change_align (AlignedWidget *aligned,
 
 	aligned_widget_change_params (aligned,
 				      basep->screen,
+				      basep->monitor,
 				      align,
 				      BORDER_POS (pos)->edge,
 				      panel->sz, basep->mode,
 				      basep->state,
 				      basep->hidebuttons_enabled,
 				      basep->hidebutton_pixmaps_enabled,
-				      panel->back_type,
-				      panel->back_pixmap,
-				      panel->fit_pixmap_bg,
-				      panel->stretch_pixmap_bg,
-				      panel->rotate_pixmap_bg,
-				      &panel->back_color);
+				      panel->background.type,
+				      panel->background.image,
+				      panel->background.fit_image,
+				      panel->background.stretch_image,
+				      panel->background.rotate_image,
+				      &panel->background.color);
 }
 
 void 
@@ -362,6 +366,7 @@ aligned_widget_change_align_edge (AlignedWidget *aligned,
 
 	aligned_widget_change_params (aligned,
 				      basep->screen,
+				      basep->monitor,
 				      align,
 				      edge,
 				      panel->sz,
@@ -369,17 +374,18 @@ aligned_widget_change_align_edge (AlignedWidget *aligned,
 				      basep->state,
 				      basep->hidebuttons_enabled,
 				      basep->hidebutton_pixmaps_enabled,
-				      panel->back_type,
-				      panel->back_pixmap,
-				      panel->fit_pixmap_bg,
-				      panel->stretch_pixmap_bg,
-				      panel->rotate_pixmap_bg,
-				      &panel->back_color);
+				      panel->background.type,
+				      panel->background.image,
+				      panel->background.fit_image,
+				      panel->background.stretch_image,
+				      panel->background.rotate_image,
+				      &panel->background.color);
 }
 				 
 GtkWidget *
-aligned_widget_new (gchar *panel_id,
+aligned_widget_new (const char *panel_id,
 		    int screen,
+		    int monitor,
 		    AlignedAlignment align,
 		    BorderEdge edge,
 		    BasePMode mode,
@@ -387,15 +393,18 @@ aligned_widget_new (gchar *panel_id,
 		    int sz,
 		    gboolean hidebuttons_enabled,
 		    gboolean hidebutton_pixmaps_enabled,
-		    PanelBackType back_type,
-		    char *back_pixmap,
+		    PanelBackgroundType back_type,
+		    const char *back_pixmap,
 		    gboolean fit_pixmap_bg,
 		    gboolean stretch_pixmap_bg,
 		    gboolean rotate_pixmap_bg,
-		    GdkColor *back_color)
+		    PanelColor *back_color)
 {
-	AlignedWidget *aligned = g_object_new (ALIGNED_TYPE_WIDGET, NULL);
-	AlignedPos *pos = g_object_new (ALIGNED_TYPE_POS, NULL);
+	AlignedWidget *aligned;
+	AlignedPos    *pos;
+
+	aligned = g_object_new (ALIGNED_TYPE_WIDGET, NULL);
+	pos = g_object_new (ALIGNED_TYPE_POS, NULL);
 	pos->align = align;
 
 	BASEP_WIDGET (aligned)->pos = BASEP_POS (pos);
@@ -403,6 +412,7 @@ aligned_widget_new (gchar *panel_id,
 	border_widget_construct (panel_id,
 				 BORDER_WIDGET (aligned),
 				 screen,
+				 monitor,
 				 edge, 
 				 TRUE,
 				 FALSE,
