@@ -53,7 +53,7 @@ struct _AlignedPosClass {
 
 GType aligned_pos_get_type (void) G_GNUC_CONST;
 
-GtkWidget *aligned_widget_new (gchar *panel_id,
+GtkWidget *aligned_widget_new (const char *panel_id,
 			       int screen,
 			       int monitor,
 			       AlignedAlignment aligned,
@@ -63,8 +63,8 @@ GtkWidget *aligned_widget_new (gchar *panel_id,
 			       int sz,
 			       gboolean hidebuttons_enabled,
 			       gboolean hidebutton_pixmaps_enabled,
-			       PanelBackType back_type,
-			       char *back_pixmap,
+			       PanelBackgroundType back_type,
+			       const char *back_pixmap,
 			       gboolean fit_pixmap_bg,
 			       gboolean stretch_pixmap_bg,
 			       gboolean rotate_pixmap_bg,
@@ -80,7 +80,7 @@ void aligned_widget_change_params (AlignedWidget *alignedw,
 				   BasePState state,
 				   gboolean hidebuttons_enabled,
 				   gboolean hidebutton_pixmaps_enabled,
-				   PanelBackType back_type,
+				   PanelBackgroundType back_type,
 				   char *pixmap_name,
 				   gboolean fit_pixmap_bg,
 				   gboolean stretch_pixmap_bg,
